@@ -39,7 +39,7 @@ metals = ["Li","Be","Na","Mg","Al","K","Ca","Sc","Ti","V",
 
 atom_num_lab = dict(zip(atom_lab_num.values(), atom_lab_num.keys()))
 
-def load_xyz(f_name, atomic_numbers=False):
+def load_xyz(f_name:str, atomic_numbers:bool=False):
     """
     Load labels and coordinates from a .xyz file
 
@@ -67,8 +67,8 @@ def load_xyz(f_name, atomic_numbers=False):
 
     return _labels, _coords
 
-def save_xyz(f_name, labels, coords, with_numbers=False, verbose=True, mask=[], 
-             atomic_numbers=False):
+def save_xyz(f_name:str, labels:list, coords:list, with_numbers:bool=False, verbose:bool=True, mask:list=[], 
+             atomic_numbers:bool=False):
     """
     Add numbers to a list of atomic labels
 
@@ -123,7 +123,7 @@ def save_xyz(f_name, labels, coords, with_numbers=False, verbose=True, mask=[],
 
     return
 
-def remove_numbers(labels):
+def remove_numbers(labels:list):
     """
     Remove numbers from a list of atomic labels
 
@@ -148,7 +148,7 @@ def remove_numbers(labels):
 
     return labels_nn
 
-def add_numbers(labels, style='per_element'):
+def add_numbers(labels:list, style:str='per_element'):
     """
     Add numbers to a list of atomic labels
 
@@ -187,7 +187,7 @@ def add_numbers(labels, style='per_element'):
 
     return labels_wn
 
-def count_elements(labels):
+def count_elements(labels:list):
     """
     Count number of each element in a list of elements
 
@@ -213,7 +213,7 @@ def count_elements(labels):
 
     return ele_count
 
-def formstr_to_formdict(form_str):
+def formstr_to_formdict(form_str:str):
     """
     Converts formula string into dictionary of {atomic label:quantity} pairs
 
@@ -236,7 +236,7 @@ def formstr_to_formdict(form_str):
 
     return form_dict
 
-def formdict_to_formstr(form_dict):
+def formdict_to_formstr(form_dict:dict):
     """
     Converts dictionary of {atomic label:quantity} pairs into a single formula string
 
@@ -273,7 +273,7 @@ def formdict_to_formstr(form_dict):
 
     return form_string
 
-def contains_metal(form_string):
+def contains_metal(form_string:str):
     """
     Returns 1 if metal found in form_string else returns a 0
 
@@ -294,7 +294,7 @@ def contains_metal(form_string):
             break
     
     return metal_found
-def combine_xyz(labels_1, labels_2, coords_1, coords_2):
+def combine_xyz(labels_1:list, labels_2:list, coords_1:list, coords_2:list):
     """
     Combine two sets of labels and coordinates
 
@@ -320,7 +320,7 @@ def combine_xyz(labels_1, labels_2, coords_1, coords_2):
 
     return labels, coords
 
-def get_neighborlist(labels, coords, adjust_cutoff = {}):
+def get_neighborlist(labels:list, coords:list, adjust_cutoff:dict={}):
     """
     Calculate ASE neighbourlist with cutoffs
 
@@ -358,7 +358,7 @@ def get_neighborlist(labels, coords, adjust_cutoff = {}):
 
     return neigh_list
 
-def get_adjacency(labels, coords, adjust_cutoff = {}, save=False, f_name="adjacency.dat"):
+def get_adjacency(labels:list, coords:list, adjust_cutoff:dict={}, save:bool=False, f_name:str="adjacency.dat"):
     """
     Calculate adjacency matrix using ASE built in cutoffs with option to modify them
 
@@ -390,8 +390,8 @@ def get_adjacency(labels, coords, adjust_cutoff = {}, save=False, f_name="adjace
 
     return adjacency
 
-def get_bonds(labels, coords, neigh_list = None, f_name='bonds.dat', save=False, verbose=True, 
-              style='indices'):
+def get_bonds(labels:list, coords:list, neigh_list=None, f_name:str='bonds.dat', save:bool=False,
+              verbose:bool=True, style:bool='indices'):
     """
     Calculate and save list of atoms between which there is a bond.
     Using ASE. Only unique angles are saved.
@@ -466,8 +466,8 @@ def get_bonds(labels, coords, neigh_list = None, f_name='bonds.dat', save=False,
 
     return bonds
 
-def get_angles(labels, coords, neigh_list = None, f_name='angles.dat', save=False, verbose=True, 
-               style='indices'):
+def get_angles(labels:list, coords:list, neigh_list=None, f_name:str='angles.dat', save:bool=False,
+              verbose:bool=True, style:bool='indices'):
     """
     Calculate and save list of atoms between which there is a bond angle.
     Using ASE. Only unique angles are saved.
@@ -542,51 +542,8 @@ def get_angles(labels, coords, neigh_list = None, f_name='angles.dat', save=Fals
 
     return angles
 
-def lab_to_num(labels):
-    '''
-    Convert atomic label to atomic number
-
-    Positional arguments:
-        labels (list) : Atomic labels
-    
-    Keyword arguments:
-        None
-
-    Returns:
-        numbers (list) : Atomic numbers
-    '''
-
-    labels_nn = remove_numbers(labels)
-
-    numbers = [atom_lab_num[lab] for lab in labels]
-    
-    return numbers
-
-def num_to_lab(numbers, numbered=True):
-    '''
-    Convert atomic number to atomic labels
-
-    Positional arguments:
-        numbers (list) : Atomic numbers
-
-    Keyword arguments:
-        numbered (bool) : Add indexing number to end of atomic labels
-
-    Returns:
-        labels (list) : Atomic labels
-    '''
-
-    labels = [atom_num_lab[num] for num in numbers]
-
-    if numbered:
-        labels_wn = add_numbers(labels)
-    else:
-        labels_wn = labels
-    
-    return labels_wn
-
-def get_dihedrals(labels, coords, neigh_list = None, f_name='dihedrals.dat', save=False, 
-                  verbose=True, style='indices'):
+def get_dihedrals(labels:list, coords:list, neigh_list=None, f_name:str='dihedrals.dat', save:bool=False,
+              verbose:bool=True, style:bool='indices'):
     """
     Calculate and save list of atoms between which there is a dihedral.
     Using ASE. Only unique angles are saved.
@@ -662,7 +619,51 @@ def get_dihedrals(labels, coords, neigh_list = None, f_name='dihedrals.dat', sav
 
     return dihedrals
 
-def reflect_coords(coords):
+
+def lab_to_num(labels:list):
+    '''
+    Convert atomic label to atomic number
+
+    Positional arguments:
+        labels (list) : Atomic labels
+    
+    Keyword arguments:
+        None
+
+    Returns:
+        numbers (list) : Atomic numbers
+    '''
+
+    labels_nn = remove_numbers(labels)
+
+    numbers = [atom_lab_num[lab] for lab in labels]
+    
+    return numbers
+
+def num_to_lab(numbers:list, numbered:bool=True):
+    '''
+    Convert atomic number to atomic labels
+
+    Positional arguments:
+        numbers (list) : Atomic numbers
+
+    Keyword arguments:
+        numbered (bool) : Add indexing number to end of atomic labels
+
+    Returns:
+        labels (list) : Atomic labels
+    '''
+
+    labels = [atom_num_lab[num] for num in numbers]
+
+    if numbered:
+        labels_wn = add_numbers(labels)
+    else:
+        labels_wn = labels
+    
+    return labels_wn
+
+def reflect_coords(coords:list):
     """
     Reflect coordinates through xy plane
 
@@ -703,8 +704,9 @@ def reflect_coords(coords):
     return coords
         
 
-def remove_broken(labels, coords, formulae, adjust_cutoff = {}, verbose = False, save = False,
-                  frag_f_name = "fragments.xyz", clean_f_name="clean.xyz", mask=[], skip = []):
+def remove_broken(labels:list, coords:list, formulae:list, adjust_cutoff:dict={}, verbose:bool=False,
+                  save:bool = False, frag_f_name:str="fragments.xyz", clean_f_name:str="clean.xyz", 
+                  mask:list=[], skip:list=[]):
     """
     Removes structures from coords which do not match formula in formulae
     Uses ASE to generate adjacency matrix and draw out bonding in coords
@@ -721,7 +723,7 @@ def remove_broken(labels, coords, formulae, adjust_cutoff = {}, verbose = False,
     Positional arguments:
         labels (list) : list of atomic labels
         coords (list) : list of lists of xyz coordinates of each atom
-        formulae (list) : list of chemical formulae
+        formulae (list) : list of chemical formulae stored as dictionaries with atomic symbol (key) count (val) pairs
 
     Keyword arguments:
         adjust_cutoff (dict)  : dictionary of atoms (keys) and new cutoffs (values)
@@ -817,7 +819,11 @@ def remove_broken(labels, coords, formulae, adjust_cutoff = {}, verbose = False,
             # Check if formula matches any of user provided formulae
             if any(form == curr_formula for form in formulae):
                 num_molecules[formdict_to_formstr(curr_formula)] += 1
-                mol_indices[formdict_to_formstr(curr_formula)].append(list(curr_frag))
+                # Reorder indices to have same label order as formula
+                # e.g. H2O --> H, H, O
+                curr_frag = list(curr_frag)
+                ord_frag = [curr_frag[o] for o in np.argsort(lab_to_num(curr_labels))]
+                mol_indices[formdict_to_formstr(curr_formula)].append(ord_frag)
             # If there are no matches, then mark the fragment as a fragment
             else:
                 for it in curr_frag :
@@ -873,7 +879,7 @@ def remove_broken(labels, coords, formulae, adjust_cutoff = {}, verbose = False,
 
     return labels_clean, coords_clean, labels_fragments, coords_fragments, mol_indices
 
-def _mask_list(_list, mask, opp_mask=False):
+def _mask_list(_list:list, mask:list, opp_mask:bool=False):
     """
     Truncates list to only include elements specified by 1 in mask
     
@@ -899,7 +905,7 @@ def _mask_list(_list, mask, opp_mask=False):
 
     return _list_masked
 
-def _reorder_list(_list, order):
+def _reorder_list(_list:list, order:list):
     """
     Reorders list using indices in order
     
@@ -919,7 +925,7 @@ def _reorder_list(_list, order):
 
     return _list_reordered
 
-def _calculate_rmsd(coords_1, coords_2):
+def _calculate_rmsd(coords_1:list, coords_2:list):
     """
     Calculates RMSD between two structures
     RMSD = sqrt(mean(deviations**2))
@@ -953,7 +959,8 @@ def _calculate_rmsd(coords_1, coords_2):
 
     return rmsd
 
-def calculate_rmsd(coords_1, coords_2, mask_1 = [], mask_2 = [], order_1 = [], order_2 = []):
+def calculate_rmsd(coords_1:list, coords_2:list, mask_1:list=[], mask_2:list=[], 
+                   order_1:list=[], order_2:list=[]):
     """
     Calculates RMSD between two structures
     RMSD = sqrt(mean(deviations**2))
@@ -1014,7 +1021,7 @@ def calculate_rmsd(coords_1, coords_2, mask_1 = [], mask_2 = [], order_1 = [], o
 
     return rmsd
 
-def rotate_coords(coords, alpha, beta, gamma):
+def rotate_coords(coords:list, alpha:float, beta:float, gamma:float):
     """
     Rotates coordinates by alpha, beta, gamma using the zyz convention
     https://easyspin.org/easyspin/documentation/eulerangles.html
@@ -1059,7 +1066,7 @@ def rotate_coords(coords, alpha, beta, gamma):
 
     return rot_coords
 
-def minimise_rmsd(coords_1, coords_2, mask_1=[], mask_2=[], order_1=[], order_2=[]):
+def minimise_rmsd(coords_1:list, coords_2:list, mask_1:list=[], mask_2:list=[], order_1:list=[], order_2:list=[]):
     """
     Minimising the RMSD between two structures
     If coords_1 and coords_2 are not the same length, then a mask array can be 
@@ -1123,7 +1130,7 @@ def minimise_rmsd(coords_1, coords_2, mask_1=[], mask_2=[], order_1=[], order_2=
 
     return rmsd, alpha, beta, gamma
 
-def _rotate_and_rmsd(angs, coords_1, coords_2):
+def _rotate_and_rmsd(angs:list, coords_1:list, coords_2:list):
     """
     Rotates coords_1 by alpha, beta, gamma using the zyz convention
     https://easyspin.org/easyspin/documentation/eulerangles.html
@@ -1132,7 +1139,7 @@ def _rotate_and_rmsd(angs, coords_1, coords_2):
     Positional arguments:
         coords_1 (list) : list of lists of xyz coordinates of each atom of first system
         coords_2 (list) : list of lists of xyz coordinates of each atom of second system
-        angs (list) : alpha, beta, gamma in radians
+        angs (list)     : alpha, beta, gamma in radians
 
     Keyword arguments:
         None
@@ -1147,4 +1154,4 @@ def _rotate_and_rmsd(angs, coords_1, coords_2):
     # Calculate rmsd between rotated first system and original second system
     rmsd = _calculate_rmsd(_coords_1, coords_2)
 
-    return rmsd
\ No newline at end of file
+    return rmsd
